@@ -8,7 +8,7 @@ rclipButton <- function(inputId, label, clipText, icon = NULL, width = NULL)
                  `data-clipboard-text` = clipText),
     tags$script(
       sprintf(
-        'var client_%s = new Clipboard( document.getElementById("%s") );',
+        'var client_%s = new ClipboardJS( document.getElementById("%s") );',
         gsub('-', '', inputId),
         inputId
       )
